<!DOCTYPE html>
<html>
<head>
  <meta charset="utf-8">
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <title>{{ escape(handler.settings["website_title"]) }}</title>
  <!-- Tell the browser to be responsive to screen width -->
  <meta content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no" name="viewport">
  <!-- Bootstrap 3.3.6 -->
  <link rel="stylesheet" href="{{ static_url("bootstrap/css/bootstrap.min.css") }}"  >
  <!-- Font Awesome -->
  <link rel="stylesheet" href="{{ static_url("res/font-awesome-4.7.0/css/font-awesome.css") }}">
  <!-- Ionicons -->
  <!-- link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/ionicons/2.0.1/css/ionicons.min.css" -->

  <link rel="stylesheet" href="{{ static_url("adminlte/css/AdminLTE.min.css") }}">
  <!-- AdminLTE Skins. Choose a skin from the css/skins
       folder instead of downloading all of them to reduce the load. -->
  <link rel="stylesheet" href="{{ static_url("adminlte/css/skins/_all-skins.min.css") }}">

  <!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
  <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
  <!--[if lt IE 9]>
  <script src="{{ static_url("res/html5shiv.min.js")}}"></script>
  <script src="{{ static_url("res/respond.min.js")}}"></script>
  <![endif]-->
    {% block head %}{% end %}
</head>


<body class="hold-transition skin-blue sidebar-mini">
<div class="wrapper">

  <header class="main-header">

    <!-- Logo -->
    <a href="/" class="logo">
      <!-- mini logo for sidebar mini 50x50 pixels -->
      <span class="logo-mini"><i class="fa fa-database" aria-hidden="true"></i></span>
      <!-- logo for regular state and mobile devices -->
      <span class="logo-lg"><i class="fa fa-database" aria-hidden="true"></i>&nbsp; Schema<b>I</b>ndex</span>
    </a>

    <!-- Header Navbar: style can be found in header.less -->
    <nav class="navbar navbar-static-top">
      <!-- Sidebar toggle button-->
      <a href="#" class="sidebar-toggle" data-toggle="offcanvas" role="button">
        <span class="sr-only">Toggle navigation</span>
      </a>
      <!-- Navbar Right Menu -->
      <div class="navbar-custom-menu">
        <ul class="nav navbar-nav">
          <!-- Messages: style can be found in dropdown.less-->
        </ul>
      </div>

    </nav>
  </header>
  <!-- Left side column. contains the logo and sidebar -->
  <aside class="main-sidebar">
    <section class="sidebar">
      <!-- Sidebar user panel -->
      <!-- sidebar menu: : style can be found in sidebar.less -->
      <ul class="sidebar-menu">
        {% if base_navigation_dict['selected_menu'] == 'overview'  %}
            <li class="active">
        {% else %}
            <li class="treeview">
        {% end %}

          <a href="/overview">
            <i class="fa fa-home"></i> <span>Home</span>
            <span class="pull-right-container"   onclick="window.location.href='/add_data_source?ds_type=hdfsindex'"  new>
              <small class="label pull-right bg-green"></small>
            </span>
          </a>
        </li>
        {% if base_navigation_dict['selected_menu'] == 'search'  %}
            <li class="active">
        {% else %}
            <li class="treeview">
        {% end %}
          <a href="/global_search">
            <i class="fa fa-search"></i> <span>Search</span>
          </a>
        </li>

        {% if base_navigation_dict['selected_menu'] == 'datasources'  %}
        <li class="active treeview menu-open">
          {% else %}
        <li class="treeview  menu-open">
          {% end %}
          <a href="#">
            <i class="fa fa-database"></i>
            <span>Data Sources</span>
                        <span class="pull-right-container">
              <i class="fa fa-angle-left pull-right"></i>
            </span>
          </a>
            <ul class="treeview-menu">



                        {% if ('selected_add_data_source' in base_navigation_dict.keys() ) %}
                          {% if base_navigation_dict['selected_add_data_source']  %}
                            <li class="active">
                          {% else %}
                            <li>
                          {% end %}
                        {% else %}
                          <li>
                        {% end %} <a href="/add_data_source">

                                <i class="fa fa-plus-square"></i> Create ... </a>
                          </li>

              {% for row in base_navigation_dict['dbrs']   %}
                        {% if ('selected_schema_name' in base_navigation_dict.keys() ) %}
                          {% if base_navigation_dict['selected_schema_name'] == row.ds_name %}
                            <li class="active">
                          {% else %}
                            <li>
                          {% end %}
                        {% else %}
                          <li>
                        {% end %}
                              <a href="/database_summary?ds_name={{ '.'.join([row.ds_name])  }}">
                              <i class="fa fa-circle-o"></i> {{ '.'.join([row.ds_name])  }} </a>
                    </li>
              {% end %}

            </ul>



        </li>


      </ul>
    </section>
    <!-- /.sidebar -->
  </aside>

  <!-- Content Wrapper. Contains page content -->
  <div class="content-wrapper">

    {% if 'message' in base_navigation_dict.keys() %}
              <div class="alert alert-{{base_navigation_dict['message']['message_type']}} alert-dismissible">
                <button type="button" class="close" data-dismiss="alert" aria-hidden="true">&times;</button>
                <h4><i class="icon fa fa-ban"></i> {{base_navigation_dict['message']['message_title']}}</h4>
                {{base_navigation_dict['message']['message_body']}}
              </div>
    {% end %}




<!-- ./wrapper -->

{# static_url("plugins/jQuery/jquery-2.2.3.min.js")  http://code.jquery.com/jquery-1.9.1.js  <script src="http://code.jquery.com/jquery-1.8.0.min.js"></script>
　　#}
<!-- jQuery 2.2.3 -->
  <script src="{{ static_url("res/jquery-2.2.3.min.js")  }} "></script>

<!-- Bootstrap 3.3.6 -->
<script src="{{ static_url("bootstrap/js/bootstrap.min.js") }}"></script>

<!-- AdminLTE App -->
<script src="{{ static_url("adminlte/js/app.min.js") }}"></script>

<script src="{{ static_url("res/bootstrap-typeahead.js")}}"></script>


    {% block main_body_right %}{% end %}




  </div>
  <!-- /.content-wrapper -->

  <footer class="main-footer">
    <div class="pull-right hidden-xs">
      <b>Version</b> 0.1
    </div>
    <strong>Copyright &copy; 2014-2018 <a href="http://almsaeedstudio.com"></a>.</strong> All rights
    reserved.
  </footer>

  <!-- Control Sidebar -->
  <aside class="control-sidebar control-sidebar-dark">
    <!-- Create the tabs -->
    <ul class="nav nav-tabs nav-justified control-sidebar-tabs">
      <li><a href="#control-sidebar-home-tab" data-toggle="tab"><i class="fa fa-home"></i></a></li>
      <li><a href="#control-sidebar-settings-tab" data-toggle="tab"><i class="fa fa-gears"></i></a></li>
    </ul>
    <!-- Tab panes -->
    <div class="tab-content">
      <!-- Home tab content -->
      <div class="tab-pane" id="control-sidebar-home-tab">
        <h3 class="control-sidebar-heading">Recent Activity</h3>
        <ul class="control-sidebar-menu">
          <li>
            <a href="javascript:void(0)">
              <i class="menu-icon fa fa-birthday-cake bg-red"></i>

              <div class="menu-info">
                <h4 class="control-sidebar-subheading">Langdon's Birthday</h4>

                <p>Will be 23 on April 24th</p>
              </div>
            </a>
          </li>
          <li>
            <a href="javascript:void(0)">
              <i class="menu-icon fa fa-user bg-yellow"></i>

              <div class="menu-info">
                <h4 class="control-sidebar-subheading">Frodo Updated His Profile</h4>

                <p>New phone +1(800)555-1234</p>
              </div>
            </a>
          </li>
          <li>
            <a href="javascript:void(0)">
              <i class="menu-icon fa fa-envelope-o bg-light-blue"></i>

              <div class="menu-info">
                <h4 class="control-sidebar-subheading">Nora Joined Mailing List</h4>

                <p>nora@example.com</p>
              </div>
            </a>
          </li>
          <li>
            <a href="javascript:void(0)">
              <i class="menu-icon fa fa-file-code-o bg-green"></i>

              <div class="menu-info">
                <h4 class="control-sidebar-subheading">Cron Job 254 Executed</h4>

                <p>Execution time 5 seconds</p>
              </div>
            </a>
          </li>
        </ul>
        <!-- /.control-sidebar-menu -->

        <h3 class="control-sidebar-heading">Tasks Progress</h3>
        <ul class="control-sidebar-menu">
          <li>
            <a href="javascript:void(0)">
              <h4 class="control-sidebar-subheading">
                Custom Template Design
                <span class="label label-danger pull-right">70%</span>
              </h4>

              <div class="progress progress-xxs">
                <div class="progress-bar progress-bar-danger" style="width: 70%"></div>
              </div>
            </a>
          </li>
          <li>
            <a href="javascript:void(0)">
              <h4 class="control-sidebar-subheading">
                Update Resume
                <span class="label label-success pull-right">95%</span>
              </h4>

              <div class="progress progress-xxs">
                <div class="progress-bar progress-bar-success" style="width: 95%"></div>
              </div>
            </a>
          </li>
          <li>
            <a href="javascript:void(0)">
              <h4 class="control-sidebar-subheading">
                Laravel Integration
                <span class="label label-warning pull-right">50%</span>
              </h4>

              <div class="progress progress-xxs">
                <div class="progress-bar progress-bar-warning" style="width: 50%"></div>
              </div>
            </a>
          </li>
          <li>
            <a href="javascript:void(0)">
              <h4 class="control-sidebar-subheading">
                Back End Framework
                <span class="label label-primary pull-right">68%</span>
              </h4>

              <div class="progress progress-xxs">
                <div class="progress-bar progress-bar-primary" style="width: 68%"></div>
              </div>
            </a>
          </li>
        </ul>
        <!-- /.control-sidebar-menu -->

      </div>
      <!-- /.tab-pane -->

      <!-- Settings tab content -->
      <div class="tab-pane" id="control-sidebar-settings-tab">
        <form method="post">
          <h3 class="control-sidebar-heading">General Settings</h3>

          <div class="form-group">
            <label class="control-sidebar-subheading">
              Report panel usage
              <input type="checkbox" class="pull-right" checked>
            </label>

            <p>
              Some information about this general settings option
            </p>
          </div>
          <!-- /.form-group -->

          <div class="form-group">
            <label class="control-sidebar-subheading">
              Allow mail redirect
              <input type="checkbox" class="pull-right" checked>
            </label>

            <p>
              Other sets of options are available
            </p>
          </div>
          <!-- /.form-group -->

          <div class="form-group">
            <label class="control-sidebar-subheading">
              Expose author name in posts
              <input type="checkbox" class="pull-right" checked>
            </label>

            <p>
              Allow the user to show his name in blog posts
            </p>
          </div>
          <!-- /.form-group -->

          <h3 class="control-sidebar-heading">Chat Settings</h3>

          <div class="form-group">
            <label class="control-sidebar-subheading">
              Show me as online
              <input type="checkbox" class="pull-right" checked>
            </label>
          </div>
          <!-- /.form-group -->

          <div class="form-group">
            <label class="control-sidebar-subheading">
              Turn off notifications
              <input type="checkbox" class="pull-right">
            </label>
          </div>
          <!-- /.form-group -->

          <div class="form-group">
            <label class="control-sidebar-subheading">
              Delete chat history
              <a href="javascript:void(0)" class="text-red pull-right"><i class="fa fa-trash-o"></i></a>
            </label>
          </div>
          <!-- /.form-group -->
        </form>
      </div>
      <!-- /.tab-pane -->
    </div>
  </aside>
  <!-- /.control-sidebar -->
  <!-- Add the sidebar's background. This div must be placed
       immediately after the control sidebar -->
  <div class="control-sidebar-bg"></div>

</div>

    {% block bottom %}{% end %}
  </body>
</html>
